package com.next.gt;

import java.awt.Component;
import java.awt.Graphics;
import java.awt.Image;
import java.awt.Panel;

public abstract class Gamelication extends Panel implements Runnable {
   public Thread runner;
   public long currentTickTimeMillis = System.currentTimeMillis();
   public long lastTickTimeMillis;
   public ActorManager actorManager = new ActorManager(this);
   public DisplayManager displayManager = new DisplayManager(this);
   public ScoreManager scoreManager;
   public AudioManager audioManager = new AudioManager();
   private String codebaseDir;
   public int SLEEP_MILLIS = 50;

   public static double randBetween(double var0, double var2) {
      if (var0 > var2) {
         double var8 = var0;
         var0 = var2;
         var2 = var8;
      }

      double var6 = var2 - var0;
      double var4 = var6 * Math.random();
      return var0 + var4;
   }

   public void init(int var1, int var2) {
      this.init(var1, var2, ".");
   }

   public void init(int var1, int var2, String var3) {
      ((Component)this).setSize(var1, var2);
      this.codebaseDir = var3;
   }

   public void start() {
      if (this.runner == null) {
         this.runner = new Thread(this);
         this.runner.start();
         (new Thread(this.audioManager)).start();
      }

   }

   public void stop() {
      if (this.runner != null) {
         this.runner.stop();
      }

      this.runner = null;
   }

   public long sleepMillis() {
      return (long)this.SLEEP_MILLIS;
   }

   public void run() {
      for(; this.runner != null; this.tick()) {
         try {
            Thread.sleep(this.sleepMillis());
         } catch (InterruptedException var1) {
         }
      }

      this.runner = null;
   }

   public void tick() {
      this.lastTickTimeMillis = this.currentTickTimeMillis;
      this.currentTickTimeMillis = System.currentTimeMillis();
      this.actorManager.tick();
      ((Component)this).repaint();
   }

   public double deltaTickTimeMillis() {
      return (double)(this.currentTickTimeMillis - this.lastTickTimeMillis);
   }

   public void update(Graphics var1) {
      this.paint(var1);
   }

   public void paint(Graphics var1) {
      this.displayManager.paint(var1);
   }

   public String getGamelicationInfo() {
      return "The Gamelication Toolkit\nVersion 0.1\nWritten by Jeremy Hutchins, jgh8962@cs.rit.edu\n\nYou are free to use, copy, and modify the source without restriction.  However, it is requested that the author is mentioned in any pertinent credit sections released with code developed with the Gamelet Toolkit.";
   }

   public String getCodeBase() {
      return this.codebaseDir;
   }

   public void showStatus(String var1) {
      System.out.println(var1);
   }

   public Image getImage(String var1, String var2) {
      return ((Component)this).getToolkit().getImage(var1 + "/" + var2);
   }

   public void play(String var1, String var2) {
      this.audioManager.play(var1 + var2);
   }
}
